| FittingEvaluationIndex | R Documentation |
This function calculates several fitting evaluation indices based on estimated and observed values.
FittingEvaluationIndex(EstiH, ObsH)
EstiH |
A numeric vector of estimated values. |
ObsH |
A numeric vector of observed values. |
EstiH and ObsH must have the same length. Non-finite pairs are
removed, and at least two finite pairs are required. R2 is NA when all
observed values are equal, and TRE is NA when all estimated values are
zero.
A named numeric vector with evaluation indices:
Mean error
Root Mean Squared Error
Coefficient of determination
Variance of the error
Total Relative Error (percentage)
FittingEvaluationIndex(c(1, 2, 4), c(1, 3, 5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.